cal.Calendar (Calendar) — amici1

# `cal.Calendar` (Calendar)

Calendar(id, name, description, color, name_de, name_fr)

Master tables : cal.Calendars (Calendars)

Slave tables : cal.SubscriptionsByCalendar (Subscriptions)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Description (description) : See `<lino.core.fields.RichTextField: description>`.

- color (color) : The color to use for entries of this calendar (in lino_xl.lib.extensible).

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.cal.models.Calendar.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.Calendar.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.Calendar.overview`.

Referenced from cal.Subscription.calendar, system.SiteConfig.site_calendar

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
name | Designation |
description | Description |
color | color | The color to use for entries of this calendar (in lino_xl.lib.extensible).
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |